@@ -428,15 +428,8 @@ _g_file_info_create_from_entry (struct archive_entry *entry,
 
 	/* times */
 
-	if (archive_entry_ctime_is_set (entry)) {
-		g_file_info_set_attribute_uint64 (info, G_FILE_ATTRIBUTE_TIME_CREATED, archive_entry_ctime (entry));
-		g_file_info_set_attribute_uint32 (info, G_FILE_ATTRIBUTE_TIME_CREATED_USEC, archive_entry_ctime_nsec (entry));
-	}
-
-	if (archive_entry_mtime_is_set (entry)) {
+	if (archive_entry_mtime_is_set (entry))
 		g_file_info_set_attribute_uint64 (info, G_FILE_ATTRIBUTE_TIME_MODIFIED, archive_entry_mtime (entry));
-		g_file_info_set_attribute_uint32 (info, G_FILE_ATTRIBUTE_TIME_MODIFIED_USEC, archive_entry_mtime_nsec (entry));
-	}
 
 	/* username */
 
@@ -529,7 +522,8 @@ restore_modification_time (GHashTable    *created_folders,
 
 		info = g_file_info_new ();
 		g_file_info_set_attribute_uint64 (info, G_FILE_ATTRIBUTE_TIME_MODIFIED, g_file_info_get_attribute_uint64 (original_info, G_FILE_ATTRIBUTE_TIME_MODIFIED));
-		g_file_info_set_attribute_uint32 (info, G_FILE_ATTRIBUTE_TIME_MODIFIED_USEC, g_file_info_get_attribute_uint32 (original_info, G_FILE_ATTRIBUTE_TIME_MODIFIED_USEC));
+		if (g_file_info_get_attribute_status (original_info, G_FILE_ATTRIBUTE_TIME_MODIFIED_USEC) == G_FILE_ATTRIBUTE_STATUS_SET)
+			g_file_info_set_attribute_uint32 (info, G_FILE_ATTRIBUTE_TIME_MODIFIED_USEC, g_file_info_get_attribute_uint32 (original_info, G_FILE_ATTRIBUTE_TIME_MODIFIED_USEC));
 		result = _g_file_set_attributes_from_info (file, info, cancellable, error);
 
 		g_object_unref (info);
@@ -757,7 +751,7 @@ extract_archive_thread (GSimpleAsyncResult *result,
 					GFileInfo *info;
 
 					info = _g_file_info_create_from_entry (entry, extract_data);
-					_g_file_set_attributes_from_info (file, info, cancellable, &load_data->error);
+					_g_file_set_attributes_from_info (file, info, cancellable, NULL);
 					g_hash_table_insert (created_folders, g_object_ref (file), g_object_ref (info));
 
 					g_object_unref (info);
@@ -780,7 +774,7 @@ extract_archive_thread (GSimpleAsyncResult *result,
 				if (r != ARCHIVE_EOF)
 					load_data->error = g_error_new_literal (FR_ERROR, FR_ERROR_COMMAND_ERROR, archive_error_string (a));
 				else
-					_g_file_set_attributes_from_entry (file, entry, extract_data, cancellable, &load_data->error);
+					_g_file_set_attributes_from_entry (file, entry, extract_data, cancellable, NULL);
 				break;
 
 			case AE_IFLNK:
@@ -811,7 +805,7 @@ extract_archive_thread (GSimpleAsyncResult *result,
 	}
 
 	if (load_data->error == NULL)
-		restore_modification_time (created_folders, cancellable, &load_data->error);
+		restore_modification_time (created_folders, cancellable, NULL);
 
 	if ((load_data->error == NULL) && (r != ARCHIVE_EOF))
 		load_data->error = g_error_new_literal (FR_ERROR, FR_ERROR_COMMAND_ERROR, archive_error_string (a));
@@ -1335,7 +1329,7 @@ save_archive_thread (GSimpleAsyncResult *result,
 	LoadData             *load_data;
 	struct archive       *a, *b;
 	struct archive_entry *r_entry;
-	int                   ra, rb;
+	int                   ra = ARCHIVE_OK, rb = ARCHIVE_OK;
 
 	save_data = g_simple_async_result_get_op_res_gpointer (result);
 	load_data = LOAD_DATA (save_data);
